@@ -28,10 +28,7 @@ fn different_dir() {
     p.cargo("build").run();
     assert!(p.build_dir().is_dir());
 
-    p.cargo("clean")
-        .cwd(&p.root().join("src"))
-        .with_stdout("")
-        .run();
+    p.cargo("clean").cwd("src").with_stdout("").run();
     assert!(!p.build_dir().is_dir());
 }
 
@@ -78,7 +75,7 @@ fn clean_multiple_packages() {
     assert!(d2_path.is_file());
 
     p.cargo("clean -p d1 -p d2")
-        .cwd(&p.root().join("src"))
+        .cwd("src")
         .with_stdout("")
         .run();
     assert!(p.bin("foo").is_file());
@@ -292,8 +289,32 @@ fn clean_verbose() {
             "\
 [REMOVING] [..]
 [REMOVING] [..]
+[REMOVING] [..]
 ",
         )
         .run();
     p.cargo("build").run();
 }
+
+#[test]
+fn clean_remove_rlib_rmeta() {
+    let p = project()
+        .file(
+            "Cargo.toml",
+            r#"
+                [package]
+                name = "foo"
+                version = "0.0.1"
+            "#,
+        )
+        .file("src/lib.rs", "")
+        .build();
+
+    p.cargo("build").run();
+    assert!(p.target_debug_dir().join("libfoo.rlib").exists());
+    let rmeta = p.glob("target/debug/deps/*.rmeta").next().unwrap().unwrap();
+    assert!(rmeta.exists());
+    p.cargo("clean -p foo").run();
+    assert!(!p.target_debug_dir().join("libfoo.rlib").exists());
+    assert!(!rmeta.exists());
+}
